@@ -43,7 +43,7 @@ get_sector_info <- function (try = FALSE, timeout = Inf) {
     if (response$status_code != 200) {
       stop(paste0("HTTP status code: ", response$status_code))
     }
-    jsonlite::fromJSON(rawToChar(response$content))
+    jsonlite::fromJSON(httr::content(response, as = "text", type = "application/json", encoding = "UTF-8"))
   })
   if (try) {
     return(try(expr = eval(expr), silent = TRUE))
